

def add(num1, num2):
    add = num1 + num2
    x = f"value of addition: {num1} + {num2} = {add}"
    return x

def sub(num1,num2):
    sub1 = num1 - num2
    x = f"value of subtraction: {num1} - {num2} = {sub1}"
    return x

def mult(num1,num2):
    mul = num1 * num2
    x = f"value of multiplication: {num1} x {num2} = {mul}"
    return x

def div(num1,num2):
    div = num1 / num2
    x = f"value of division: {num1} / {num2} = {div}"
    return x


